//+------------------------------------------------------------------+
//|                                                       trades.mqh |
//|                                                           Mihail |
//|                                                textyping@mail.ru |
//+------------------------------------------------------------------+
#property copyright "Mihail"
#property link      "textyping@mail.ru"
#property strict

/*
 - Input Parameters:
 
input    int               magic                   = 168737;                                    // Magic Number
input    double            lot                     = 0.1;                                       // Lot Size
input    int               Slippage                = 100;
input    double            StopLoss                = 0;                                         // Stop Loss (0 - OFF)
input    double            TakeProfit              = 0;                                         // Take Profit (0 - OFF)
input    string            comment                 = "";                                        // Comment

 - Point and pipMultiplier and lotsDigits calculation:         void     pointCalculation()
 - Prefix/Postfix determining                                  void     prefixPostfix()
 - Open Buy market order:                                      int      openBuy()
                                                               int      openBuyStop          (double openPrice)
                                                               int      openBuyLimit         (double openPrice)
 - Open Sell market order:                                     int      openSell()
                                                               int      openSellStop         (double openPrice)
                                                               int      openSellLimit        (double openPrice)
 - Close All Buy market orders                                 void     closeBuy()
 - Close All Sell market orders                                void     closeSell()
 - Close All Market orders                                     void     closeAll()
                                                               void     close50volume()
                                                               void     closeLoss()
                                                               void     closeProfit()
                                                               void     deleteAllPending()
 - Profit per All opened trades                                double   profitOfOpenedTrades()
 - Calculation of Lot Size for Risk and Stop Loss (pips):      double   riskLotCalculation   (double risk, double stLoss)
   need: prefixPostfix(), pointCalculation().
                                                               double   riskCalculationLot   (double lot2, double StopLoss2)
                                                               double   pointsPrice()
 - Calculation of Lot Size for Profit and Take Profit (pips):  double   profitLotCalculation (double prof, double tkProfit)
   need: prefixPostfix(), pointCalculation().  
 - Quantity of opened Buy trades by magic and Symbol           int      numberOfOpenedBuy()
 - Quantity of opened Sell trades by magic and Symbol          int      numberOfOpenedSell()
 - Quantity of opened Buy and Sell trades by magic and Symbol  int      numberOfOpenedBuySell()
                                                               int      numberOfPending()
                                                               int      numderInLoss()
                                                               int      numberInProfit()
 
 
*/

//+------------------------------------------------------------------+
//| defines                                                          |
//+------------------------------------------------------------------+
// #define MacrosHello   "Hello, world!"
// #define MacrosYear    2010
//+------------------------------------------------------------------+
//| DLL imports                                                      |
//+------------------------------------------------------------------+
// #import "user32.dll"
//   int      SendMessageA(int hWnd,int Msg,int wParam,int lParam);
// #import "my_expert.dll"
//   int      ExpertRecalculate(int wParam,int lParam);
// #import
//+------------------------------------------------------------------+
//| EX5 imports                                                      |
//+------------------------------------------------------------------+
// #import "stdlib.ex5"
//   string ErrorDescription(int error_code);
// #import
//+------------------------------------------------------------------+
 
//+------------------------------------------------------------------+

double   _point,  pipsMultiplier;

int      lotsDigits;

void pointCalculation()
 {
  _point = 1;
  pipsMultiplier = 1;
   
  if(Digits == 5 || Digits == 3)
   {
    _point = Point * 10;
    pipsMultiplier = 10;
   }
  else
   {
    _point = Point;
    pipsMultiplier = 1;
   }
   
  lotsDigits = int(MathCeil(MathAbs(MathLog( MarketInfo(_Symbol, MODE_LOTSTEP) )/MathLog(10))));
 }
 
//+------------------------------------------------------------------+

string   prefix, postfix, SMB;

void prefixPostfix()
 {
  prefix = "";
  postfix = "";
  int len = StringLen(_Symbol);
  if (len == 6) 
   {
    SMB = _Symbol;
    return;
   }

  bool prefixFound = false;
  for (int i = 0; i < len; i++)
   {
    int symb = StringGetChar(_Symbol, i);
    if (!prefixFound && (symb < 65 || symb > 90))
     {
      prefix += StringSubstr(_Symbol, i, 1);
     }
    else
     {
      prefixFound = true;
     }
    if (prefixFound && (symb < 65 || symb > 90))
     {
      postfix += StringSubstr(_Symbol, i, 1);
     }
    else
     {
      SMB += StringSubstr(_Symbol, i, 1);
     } 
   }
 }
           
//+------------------------------------------------------------------+ 

int openBuy()
 {
  double SL;
  double TP;
  if (StopLoss == 0) SL = 0;
  else SL = Ask - StopLoss * _point;
  if (TakeProfit == 0) TP = 0;
  else TP = Ask + TakeProfit * _point;
  int Ans = OrderSend(Symbol(), OP_BUY, lot, Ask, Slippage, SL, TP, comment, magic, 0);
  if (Ans > 0) 
   {
    Alert ("BUY order is opened. Lot size = ", lot, ", SL = ", SL, ", TP = ", TP); 
   }
  else
   {
    Alert ("Error of opening the BUY order. Lot size = ", lot, ", SL = ", SL, ", TP = ", TP, ". Error: ", GetLastError());
   }
  return Ans;
 }
           
//+------------------------------------------------------------------+ 

int openBuyStop(double openPrice)
 {
  double SL;
  double TP;
  if (StopLoss == 0) SL = 0;
  else SL = openPrice - StopLoss * _point;
  if (TakeProfit == 0) TP = 0;
  else TP = openPrice + TakeProfit * _point;
  int Ans = OrderSend(Symbol(), OP_BUYSTOP, lot, openPrice, Slippage, SL, TP, comment, magic, 0);
  if (Ans > 0) 
   {
    Alert ("BUY STOP order placed. Entry price = ", openPrice, ", Lot size = ", lot, ", SL = ", SL, ", TP = ", TP); 
   }
  else
   {
    Alert ("Error of placing the BUY STOP order. Entry price = ", openPrice, ", Lot size = ", lot, ", SL = ", SL, ", TP = ", TP, ". Error: ", GetLastError());
   }
  return Ans;
 }
           
//+------------------------------------------------------------------+ 

int openBuyLimit(double openPrice)
 {
  double SL;
  double TP;
  if (StopLoss == 0) SL = 0;
  else SL = openPrice - StopLoss * _point;
  if (TakeProfit == 0) TP = 0;
  else TP = openPrice + TakeProfit * _point;
  int Ans = OrderSend(Symbol(), OP_BUYLIMIT, lot, openPrice, Slippage, SL, TP, comment, magic, 0);
  if (Ans > 0) 
   {
    Alert ("BUY LIMIT order placed. Entry price = ", openPrice, ", Lot size = ", lot, ", SL = ", SL, ", TP = ", TP); 
   }
  else
   {
    Alert ("Error of placing the BUY LIMIT order. Entry price = ", openPrice, ", Lot size = ", lot, ", SL = ", SL, ", TP = ", TP, ". Error: ", GetLastError());
   }
  return Ans;
 }
 
//+------------------------------------------------------------------+

int openSell()
 {
  double SL;
  double TP;
  if (StopLoss == 0) SL = 0;
  else SL = Bid + StopLoss * _point;
  if (TakeProfit == 0) TP = 0;
  else TP = Bid - TakeProfit * _point;
  int Ans = OrderSend(_Symbol, OP_SELL, lot, Bid, Slippage, SL, TP, comment, magic, 0);
  if (Ans > 0)
   {
    Alert ("SELL order is opened. Lot size = ", lot, ", SL = ", SL, ", TP = ", TP); 
   }
  else
   {
    Alert ("Error of opening the SELL order. Lot size = ", lot, ", SL = ", SL, ", TP = ", TP, ". Error: ", GetLastError());
   }
  return Ans;
 }
 
//+------------------------------------------------------------------+

int openSellStop(double openPrice)
 {
  double SL;
  double TP;
  if (StopLoss == 0) SL = 0;
  else SL = openPrice + StopLoss * _point;
  if (TakeProfit == 0) TP = 0;
  else TP = openPrice - TakeProfit * _point;
  int Ans = OrderSend(_Symbol, OP_SELLSTOP, lot, openPrice, Slippage, SL, TP, comment, magic, 0);
  if (Ans > 0)
   {
    Alert ("SELL STOP order is opened. Entry price = ", openPrice, ", Lot size = ", lot, ", SL = ", SL, ", TP = ", TP); 
   }
  else
   {
    Alert ("Error of opening the SELL STOP order. Entry price = ", openPrice, ", Lot size = ", lot, ", SL = ", SL, ", TP = ", TP, ". Error: ", GetLastError());
   }
  return Ans;
 }
 
//+------------------------------------------------------------------+

int openSellLimit(double openPrice)
 {
  double SL;
  double TP;
  if (StopLoss == 0) SL = 0;
  else SL = openPrice + StopLoss * _point;
  if (TakeProfit == 0) TP = 0;
  else TP = openPrice - TakeProfit * _point;
  int Ans = OrderSend(_Symbol, OP_SELLLIMIT, lot, openPrice, Slippage, SL, TP, comment, magic, 0);
  if (Ans > 0)
   {
    Alert ("SELL LIMIT order is opened. Entry price = ", openPrice, ", Lot size = ", lot, ", SL = ", SL, ", TP = ", TP); 
   }
  else
   {
    Alert ("Error of opening the SELL LIMIT order. Entry price = ", openPrice, ", Lot size = ", lot, ", SL = ", SL, ", TP = ", TP, ". Error: ", GetLastError());
   }
  return Ans;
 }
 
//+------------------------------------------------------------------+ 
 
void closeBuy()
 {
  for (int i = OrdersTotal() - 1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderSymbol() != _Symbol) continue;
    if (OrderMagicNumber() != magic) continue;
    if (OrderType() == OP_BUY) 
     {
      Print (_Symbol, ": Trying to close BUY order.");
      bool Ans = OrderClose(OrderTicket(), OrderLots(), OrderClosePrice(), Slippage);
      if (Ans)
       {
        Print (_Symbol, ": BUY order is closed.");
       }
      else
       {
        Print (_Symbol, ": Failed to close the BUY order.");
       }
     }
   }
 }
 
//+------------------------------------------------------------------+ 
 
void closeBuyAll()
 {
  for (int i = OrdersTotal() - 1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderType() == OP_BUY) 
     {
      Print (_Symbol, ": Trying to close BUY order.");
      bool Ans = OrderClose(OrderTicket(), OrderLots(), OrderClosePrice(), Slippage);
      if (Ans)
       {
        Print (_Symbol, ": BUY order is closed.");
       }
      else
       {
        Print (_Symbol, ": Failed to close the BUY order.");
       }
     }
   }
 }
 
//+------------------------------------------------------------------+ 
 
void closeSell()
 {
  for (int i = OrdersTotal() - 1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderSymbol() != _Symbol) continue;
    if (OrderMagicNumber() != magic) continue;
    if (OrderType() == OP_SELL) 
     {
      Print ("Trying to close SELL order.");
      bool Ans = OrderClose(OrderTicket(), OrderLots(), OrderClosePrice(), Slippage);
      if (Ans)
       {
        Print (_Symbol, ": SELL order is closed.");
       }
      else
       {
        Print (_Symbol, ": Failed to close the SELL order.");
       }
     }
   }
 }
 
//+------------------------------------------------------------------+ 
 
void closeSellAll()
 {
  for (int i = OrdersTotal() - 1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderType() == OP_SELL) 
     {
      Print ("Trying to close SELL order.");
      bool Ans = OrderClose(OrderTicket(), OrderLots(), OrderClosePrice(), Slippage);
      if (Ans)
       {
        Print (_Symbol, ": SELL order is closed.");
       }
      else
       {
        Print (_Symbol, ": Failed to close the SELL order.");
       }
     }
   }
 }
 
//+------------------------------------------------------------------+
 
void closeAll()
 {
  for (int i = OrdersTotal()-1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderSymbol() != _Symbol) continue;
    if (OrderMagicNumber() != magic) continue;
    if (OrderType() == OP_SELL || OrderType() == OP_BUY) 
     {
      Print ("Trying to close order.");
      int Ans = OrderClose(OrderTicket(), OrderLots(), OrderClosePrice(), Slippage);
      if (Ans)
       {
        Print (_Symbol, ": Order is closed.");
       }
      else
       {
        Print (_Symbol, ": Failed to close the order.");
       }
     }
   }
 }
 
//+------------------------------------------------------------------+
 
void closeAllAll()
 {
  for (int i = OrdersTotal()-1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderType() == OP_SELL || OrderType() == OP_BUY) 
     {
      Print ("Trying to close order.");
      int Ans = OrderClose(OrderTicket(), OrderLots(), OrderClosePrice(), Slippage);
      if (Ans)
       {
        Print (_Symbol, ": Order is closed.");
       }
      else
       {
        Print (_Symbol, ": Failed to close the order.");
       }
     }
   }
 }
 
//+------------------------------------------------------------------+
 
void close50volume()
 {
  for (int i = OrdersTotal()-1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderSymbol() != _Symbol) continue;
    if (OrderMagicNumber() != magic) continue;
    if (OrderType() == OP_SELL || OrderType() == OP_BUY) 
     {
      double closingVolume = NormalizeDouble (OrderLots() / 2, lotsDigits);
      Print ("Trying to close 50% of volume.");
      int Ans = OrderClose(OrderTicket(), closingVolume, OrderClosePrice(), Slippage);
      if (Ans)
       {
        Print (_Symbol, ": Closing of 50% is successful.");
       }
      else
       {
        Print (_Symbol, ": Failed to close 50% of volume.");
       }
     }
   }
 }
 
//+------------------------------------------------------------------+
 
void close50volumeAll()
 {
  for (int i = OrdersTotal()-1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderType() == OP_SELL || OrderType() == OP_BUY) 
     {
      double closingVolume = NormalizeDouble (OrderLots() / 2, lotsDigits);
      Print ("Trying to close 50% of volume.");
      int Ans = OrderClose(OrderTicket(), closingVolume, OrderClosePrice(), Slippage);
      if (Ans)
       {
        Print (_Symbol, ": Closing of 50% is successful.");
       }
      else
       {
        Print (_Symbol, ": Failed to close 50% of volume.");
       }
     }
   }
 }
 
//+------------------------------------------------------------------+
 
void closeLoss()
 {
  for (int i = OrdersTotal()-1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderSymbol() != _Symbol) continue;
    if (OrderMagicNumber() != magic) continue;
    if (OrderProfit() >= 0) continue;
    if (OrderType() == OP_SELL || OrderType() == OP_BUY) 
     {
      Print ("Trying to close order.");
      int Ans = OrderClose(OrderTicket(), OrderLots(), OrderClosePrice(), Slippage);
      if (Ans)
       {
        Print (_Symbol, ": Order is closed.");
       }
      else
       {
        Print (_Symbol, ": Failed to close the order.");
       }
     }
   }
 }
 
//+------------------------------------------------------------------+
 
void closeLossAll()
 {
  for (int i = OrdersTotal()-1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderProfit() >= 0) continue;
    if (OrderType() == OP_SELL || OrderType() == OP_BUY) 
     {
      Print ("Trying to close order.");
      int Ans = OrderClose(OrderTicket(), OrderLots(), OrderClosePrice(), Slippage);
      if (Ans)
       {
        Print (_Symbol, ": Order is closed.");
       }
      else
       {
        Print (_Symbol, ": Failed to close the order.");
       }
     }
   }
 }
 
//+------------------------------------------------------------------+
 
void closeProfit()
 {
  for (int i = OrdersTotal()-1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderSymbol() != _Symbol) continue;
    if (OrderMagicNumber() != magic) continue;
    if (OrderProfit() <= 0) continue;
    if (OrderType() == OP_SELL || OrderType() == OP_BUY) 
     {
      Print ("Trying to close order.");
      int Ans = OrderClose(OrderTicket(), OrderLots(), OrderClosePrice(), Slippage);
      if (Ans)
       {
        Print (_Symbol, ": Order is closed.");
       }
      else
       {
        Print (_Symbol, ": Failed to close the order.");
       }
     }
   }
 }
 
//+------------------------------------------------------------------+
 
void closeProfitAll()
 {
  for (int i = OrdersTotal()-1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderProfit() <= 0) continue;
    if (OrderType() == OP_SELL || OrderType() == OP_BUY) 
     {
      Print ("Trying to close order.");
      int Ans = OrderClose(OrderTicket(), OrderLots(), OrderClosePrice(), Slippage);
      if (Ans)
       {
        Print (_Symbol, ": Order is closed.");
       }
      else
       {
        Print (_Symbol, ": Failed to close the order.");
       }
     }
   }
 }

//+------------------------------------------------------------------+
 
void deleteAllPending()
 {
  for (int i = OrdersTotal()-1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderSymbol() != _Symbol) continue;
    if (OrderMagicNumber() != magic) continue;
    if (OrderType() == OP_SELLLIMIT || OrderType() == OP_SELLSTOP || OrderType() == OP_BUYLIMIT || OrderType() == OP_BUYSTOP) 
     {
      Print ("Trying to delete order.");
      int Ans = OrderDelete(OrderTicket());
      if (Ans)
       {
        Print (_Symbol, ": Order is deleted.");
       }
      else
       {
        Print (_Symbol, ": Failed to delete the order.");
       }
     }
   }
 }

//+------------------------------------------------------------------+
 
void deleteAllPendingAll()
 {
  for (int i = OrdersTotal()-1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderType() == OP_SELLLIMIT || OrderType() == OP_SELLSTOP || OrderType() == OP_BUYLIMIT || OrderType() == OP_BUYSTOP) 
     {
      Print ("Trying to delete order.");
      int Ans = OrderDelete(OrderTicket());
      if (Ans)
       {
        Print (_Symbol, ": Order is deleted.");
       }
      else
       {
        Print (_Symbol, ": Failed to delete the order.");
       }
     }
   }
 }

//+------------------------------------------------------------------+ 

double profitOfOpenedTrades()
 {
  double result = 0;
  for (int i = OrdersTotal() - 1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderSymbol() != _Symbol) continue;
    if (OrderMagicNumber() != magic) continue;
    if (OrderType() == OP_SELL || OrderType() == OP_BUY) 
     {
      result += OrderProfit();
     }
   }
  return result;
 }
  
//+------------------------------------------------------------------+ 

double riskLotCalculation(double risk, double stLoss)
 {
  stLoss *= _point;
  double  pointPrice = MarketInfo(_Symbol,MODE_TICKVALUE) / Point;

  if (pointPrice == 0)
   {
    Alert("The broker does not provide the cost of one point for this instrument.");
    ExpertRemove();
   }
  
  double equity = AccountEquity();
  double fixedAmount = NormalizeDouble (risk * equity / 100, 2);
  double result = NormalizeDouble(fixedAmount / (pointPrice * stLoss), lotsDigits);
   
  if (result < MarketInfo(_Symbol,MODE_MINLOT))
   {
 //   result = MarketInfo(_Symbol,MODE_MINLOT);
    Alert ("Lot Size can't be less than ", result);
   }
  else if (result > MarketInfo(_Symbol,MODE_MAXLOT))
   {
 //   result = MarketInfo(_Symbol,MODE_MAXLOT);
    Alert ("Lot Size can't be more than ", result);
   }
  Print ("Lot Size calculated = ", result); 

  return result; 
 }
  
//+------------------------------------------------------------------+ 

double   pointsPrice()
 {
  double  pointPrice = MarketInfo(_Symbol,MODE_TICKVALUE) / Point;
 
  if (pointPrice == 0)
   {
    Alert("The broker does not provide the cost of one point for this instrument.");
   }
  
  return pointPrice; 
 }

//+------------------------------------------------------------------+ 

double riskCalculationLot (double lot2, double StopLoss2)
 {
  StopLoss2 *= _point;
  double  pointPrice = MarketInfo(_Symbol,MODE_TICKVALUE) / Point;

  if (pointPrice == 0)
   {
    Alert("The broker does not provide the cost of one point for this instrument.");
    ExpertRemove();
   }
  
  if (StopLoss2 <= 0)
   {
    Alert ("Risk can't be calculated.");
    return 0;
   }
  
  double fixedAmount = NormalizeDouble(lot2 * pointPrice * StopLoss2, 2);
   
  return fixedAmount; 
 }

//+------------------------------------------------------------------+ 

double profitLotCalculation(double prof, double tkProfit)

 {
  double  pointPrice = MarketInfo(_Symbol,MODE_TICKVALUE) / Point;

  if (pointPrice == 0)
   {
    Alert("The broker does not provide the cost of one point for this instrument.");
    ExpertRemove();
   }
   
  double result = NormalizeDouble(prof / (pointPrice * tkProfit), lotsDigits);
  
  if (result < MarketInfo(_Symbol,MODE_MINLOT))
   {
    result = MarketInfo(_Symbol,MODE_MINLOT);
    Print ("Lot Size can't be less than ", result);
   }
  else if (result > MarketInfo(_Symbol,MODE_MAXLOT))
   {
    result = MarketInfo(_Symbol,MODE_MAXLOT);
    Print ("Lot Size can't be more than ", result);
   }
  Print ("Lot Size calculated = ", result); 
      
  return result;  
 }
 
//+------------------------------------------------------------------+ 

int numberOfOpenedBuy()
 {
  int result = 0;
  for (int i = OrdersTotal() - 1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderSymbol() != _Symbol) continue;
    if (OrderMagicNumber() != magic) continue;
    if (OrderType() == OP_BUY) 
     {
      result++;
     }
   }
  return result;
 }
 
//+------------------------------------------------------------------+ 

int numberOfOpenedBuyAll()
 {
  int result = 0;
  for (int i = OrdersTotal() - 1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderType() == OP_BUY) 
     {
      result++;
     }
   }
  return result;
 }
  
//+------------------------------------------------------------------+ 

int numberOfOpenedSell()
 {
  int result = 0;
  for (int i = OrdersTotal() - 1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderSymbol() != _Symbol) continue;
    if (OrderMagicNumber() != magic) continue;
    if (OrderType() == OP_SELL) 
     {
      result++;
     }
   }
  return result;
 }
  
//+------------------------------------------------------------------+ 

int numberOfOpenedSellAll()
 {
  int result = 0;
  for (int i = OrdersTotal() - 1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderType() == OP_SELL) 
     {
      result++;
     }
   }
  return result;
 }
  
//+------------------------------------------------------------------+ 

int numberOfOpenedBuySell()
 {
  int result = 0;
  for (int i = OrdersTotal() - 1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderSymbol() != _Symbol) continue;
    if (OrderMagicNumber() != magic) continue;
    if (OrderType() == OP_SELL || OrderType() == OP_BUY) 
     {
      result++;
     }
   }
  return result;
 }
  
//+------------------------------------------------------------------+ 

int numberOfOpenedBuySellAll()
 {
  int result = 0;
  for (int i = OrdersTotal() - 1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderType() == OP_SELL || OrderType() == OP_BUY) 
     {
      result++;
     }
   }
  return result;
 }

//+------------------------------------------------------------------+ 

int numberOfPending()
 {
  int result = 0;
  for (int i = OrdersTotal() - 1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderSymbol() != _Symbol) continue;
    if (OrderMagicNumber() != magic) continue;
    if (OrderType() == OP_SELLSTOP || OrderType() == OP_SELLLIMIT || OrderType() == OP_BUYSTOP || OrderType() == OP_BUYLIMIT) 
     {
      result++;
     }
   }
  return result;
 }

//+------------------------------------------------------------------+ 

int numberOfPendingAll()
 {
  int result = 0;
  for (int i = OrdersTotal() - 1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderType() == OP_SELLSTOP || OrderType() == OP_SELLLIMIT || OrderType() == OP_BUYSTOP || OrderType() == OP_BUYLIMIT) 
     {
      result++;
     }
   }
  return result;
 }
  
//+------------------------------------------------------------------+ 

int numderInLoss()
 {
  int result = 0;
  for (int i = OrdersTotal() - 1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderSymbol() != _Symbol) continue;
    if (OrderMagicNumber() != magic) continue;
    if (OrderProfit() >= 0) continue;
    if (OrderType() == OP_SELL || OrderType() == OP_BUY) 
     {
      result++;
     }
   }
  return result;
 }
  
//+------------------------------------------------------------------+ 

int numderInLossAll()
 {
  int result = 0;
  for (int i = OrdersTotal() - 1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderProfit() >= 0) continue;
    if (OrderType() == OP_SELL || OrderType() == OP_BUY) 
     {
      result++;
     }
   }
  return result;
 }
  
//+------------------------------------------------------------------+ 

int numberInProfit()
 {
  int result = 0;
  for (int i = OrdersTotal() - 1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderSymbol() != _Symbol) continue;
    if (OrderMagicNumber() != magic) continue;
    if (OrderProfit() <= 0) continue;
    if (OrderType() == OP_SELL || OrderType() == OP_BUY) 
     {
      result++;
     }
   }
  return result;
 }
  
//+------------------------------------------------------------------+ 

int numberInProfitAll()
 {
  int result = 0;
  for (int i = OrdersTotal() - 1; i >= 0; i--)
   {
    if (!OrderSelect(i,SELECT_BY_POS)) continue;
    if (OrderProfit() <= 0) continue;
    if (OrderType() == OP_SELL || OrderType() == OP_BUY) 
     {
      result++;
     }
   }
  return result;
 }
  
//+------------------------------------------------------------------+ 

string ordersType(int OP)
 {
  switch(OP)
   {
    case 0:
     return "BUY";
    case 1:
     return "SELL";
    case 2:
     return "BUY LIMIT";
    case 3:
     return "SELL LIMIT";
    case 4:
     return "BUY STOP";
    case 5:
     return "SELL STOP";
   }
  return "";
 }
   
//+------------------------------------------------------------------+ 

